@@ -36,4 +36,10 @@ def lib1_double_add(a, b):
     c = add_x(a, b)
     return 2 * c
 
+def new_add(a, b):
+    return a + b + 100
+
+
+
+
 
